summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlistpatternedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlistpatternedit.h')
-rw-r--r--kpovmodeler/pmlistpatternedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmlistpatternedit.h b/kpovmodeler/pmlistpatternedit.h
index 4e80e4d8..4b34ee93 100644
--- a/kpovmodeler/pmlistpatternedit.h
+++ b/kpovmodeler/pmlistpatternedit.h
@@ -42,9 +42,9 @@ class PMListPatternEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMListPatternEdit with tqparent and name
*/
- PMListPatternEdit( TQWidget* tqparent, const char* name = 0 );
+ PMListPatternEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -42,9 +42,9 @@ class PMListPatternEdit : public PMDialogEditBase
public:
/**
- * Creates a PMListPatternEdit with tqparent and name
+ * Creates a PMListPatternEdit with parent and name
*/